@@ -480,12 +480,12 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
             delta = timedelta(days=days)
             dtbegin = dtend - delta
         else:
-            dtbegin = pd.Timestamp(pytz.timezone(NY).localize(dtbegin))
+            dtbegin = pd.Timestamp(pytz.timezone('UTC').localize(dtbegin))
         while dtbegin > dtend:
             # if we start the script during market hours we could get this
             # situation. this resolves that.
             dtbegin -= timedelta(days=1)
-        return dtbegin, dtend.astimezone(NY)
+        return dtbegin.astimezone(NY), dtend.astimezone(NY)
 
     def get_aggs_from_polygon(self,
                               dataname,
